__version__ = "0.1.0"

from .solver import CaptchaSolver, FailedCaptcha, InvalidKey, InvalidMethod, FailedBalance

__all__ = [
    "CaptchaSolver",
    "FailedCaptcha",
    "InvalidKey",
    "InvalidMethod",
    "FailedBalance",
]
